@@ -61,21 +61,21 @@ static ssize_t readwait(int fd, /*@out@*/void *buf, size_t count) {
 
 	totalread = 0;
 
-	while( count > 0 ) {
+	while (count > 0) {
 		ssize_t s;
 
-		s = read(fd,buf,count);
-		if( s < 0 )
+		s = read(fd, buf, count);
+		if (s < 0)
 			return s;
-		if( interrupted() ) {
+		if (interrupted()) {
 			errno = EINTR;
 			return -1;
 		}
-		if( (size_t)s > count ) {
+		if ((size_t)s > count) {
 			errno = EINVAL;
 			return -1;
 		}
-		if( s == 0 )
+		if (s == 0)
 			break;
 		totalread += s;
 		buf += s;
@@ -89,13 +89,13 @@ retvalue ar_open(/*@out@*/struct ar_archive **n, const char *filename) {
 	char buffer[sizeof(AR_MAGIC)];
 	ssize_t bytesread;
 
-	if( interrupted() )
+	if (interrupted())
 		return RET_ERROR_INTERRUPTED;
-	ar = calloc(1,sizeof(struct ar_archive));
-	if( ar == NULL )
+	ar = zNEW(struct ar_archive);
+	if (FAILEDTOALLOC(ar))
 		return RET_ERROR_OOM;
-	ar->fd = open(filename,O_NOCTTY|O_RDONLY);
-	if( ar->fd < 0 ) {
+	ar->fd = open(filename, O_NOCTTY|O_RDONLY);
+	if (ar->fd < 0) {
 		int e = errno;
 		fprintf(stderr, "Error %d opening %s: %s\n",
 				e, filename, strerror(e));
@@ -103,28 +103,31 @@ retvalue ar_open(/*@out@*/struct ar_archive **n, const char *filename) {
 		return RET_ERRNO(e);
 	}
 
-	bytesread = readwait(ar->fd,buffer,sizeof(AR_MAGIC)-1);
-	if( bytesread != sizeof(AR_MAGIC)-1 ) {
+	bytesread = readwait(ar->fd, buffer, sizeof(AR_MAGIC) - 1);
+	if (bytesread != sizeof(AR_MAGIC)-1) {
 		int e = errno;
 		(void)close(ar->fd);
 		free(ar);
-		if( bytesread < 0 ) {
+		if (bytesread < 0) {
 			fprintf(stderr, "Error %d reading from %s: %s\n",
 					e, filename, strerror(e));
 			return RET_ERRNO(e);
 		} else {
-			fprintf(stderr,"Premature end of reading from %s\n",filename);
+			fprintf(stderr, "Premature end of reading from %s\n",
+					filename);
 			return RET_ERROR;
 		}
 	}
-	if( memcmp(buffer,AR_MAGIC,sizeof(AR_MAGIC)-1) != 0 ) {
+	if (memcmp(buffer, AR_MAGIC, sizeof(AR_MAGIC)-1) != 0) {
 		(void)close(ar->fd);
 		free(ar);
-		fprintf(stderr, "Missing ar header '!<arch>' at the beginning of %s\n", filename);
+		fprintf(stderr,
+"Missing ar header '!<arch>' at the beginning of %s\n",
+				filename);
 		return RET_ERROR;
 	}
 	ar->filename = strdup(filename);
-	if( ar->filename == NULL ) {
+	if (FAILEDTOALLOC(ar->filename)) {
 		close(ar->fd);
 		free(ar);
 		return RET_ERROR_OOM;
@@ -136,8 +139,8 @@ retvalue ar_open(/*@out@*/struct ar_archive **n, const char *filename) {
 }
 
 void ar_close(/*@only@*/struct ar_archive *ar) {
-	if( ar != NULL ) {
-		if( ar->fd >= 0 )
+	if (ar != NULL) {
+		if (ar->fd >= 0)
 			(void)close(ar->fd);
 		free(ar->filename);
 		free(ar);
@@ -145,7 +148,7 @@ void ar_close(/*@only@*/struct ar_archive *ar) {
 }
 
 /* RET_OK = next is there, RET_NOTHING = eof, < 0 = error */
-retvalue ar_nextmember(struct ar_archive *ar,/*@out@*/char **filename) {
+retvalue ar_nextmember(struct ar_archive *ar, /*@out@*/char **filename) {
 	ssize_t bytesread;
 	char *p;
 	off_t s;
@@ -155,25 +158,26 @@ retvalue ar_nextmember(struct ar_archive *ar,/*@out@*/char **filename) {
 
 	/* seek over what is left from the last part: */
 	s = lseek(ar->fd, ar->next_position, SEEK_SET);
-	if( s == (off_t)-1 ) {
+	if (s == (off_t)-1) {
 		int e = errno;
 		fprintf(stderr,
-				"Error %d seeking to next member in ar file %s: %s\n",
+"Error %d seeking to next member in ar file %s: %s\n",
 				e, ar->filename, strerror(e));
 		return RET_ERRNO(e);
 	}
 	/* read the next header from the file */
 
-	if( interrupted() )
+	if (interrupted())
 		return RET_ERROR_INTERRUPTED;
 
-	bytesread = readwait(ar->fd,&ar->currentheader,sizeof(ar->currentheader));
+	bytesread = readwait(ar->fd, &ar->currentheader,
+			sizeof(ar->currentheader));
 	ar->next_position += sizeof(ar->currentheader);
-	if( bytesread == 0 )
+	if (bytesread == 0)
 		return RET_NOTHING;
-	if( bytesread != sizeof(ar->currentheader) ){
+	if (bytesread != sizeof(ar->currentheader)){
 		int e = errno;
-		if( bytesread < 0 ) {
+		if (bytesread < 0) {
 			fprintf(stderr,
 "Error %d reading from ar file %s: %s\n",
 				e, ar->filename, strerror(e));
@@ -184,7 +188,7 @@ retvalue ar_nextmember(struct ar_archive *ar,/*@out@*/char **filename) {
 			return RET_ERROR;
 		}
 	}
-	if( memcmp(ar->currentheader.ah_magictrailer,AR_HEADERMAGIC,2) != 0 ) {
+	if (memcmp(ar->currentheader.ah_magictrailer, AR_HEADERMAGIC, 2) != 0) {
 		fprintf(stderr, "Corrupt ar file %s\n", ar->filename);
 		return RET_ERROR;
 	}
@@ -192,33 +196,35 @@ retvalue ar_nextmember(struct ar_archive *ar,/*@out@*/char **filename) {
 	/* calculate the length and mark possible fillers being needed */
 
 	/* make ah_size null-terminated by overwriting the following field */
-	assert( &ar->currentheader.ah_magictrailer[0] == ar->currentheader.ah_size + 10 );
+	assert (&ar->currentheader.ah_magictrailer[0]
+			== ar->currentheader.ah_size + 10);
 	ar->currentheader.ah_magictrailer[0] = '\0';
 
-	ar->member_size = strtoul(ar->currentheader.ah_size,&p,10);
-	if( *p != '\0' && *p != ' ' ) {
-		fprintf(stderr, "Error calculating length field in ar file %s\n",
+	ar->member_size = strtoul(ar->currentheader.ah_size, &p, 10);
+	if (*p != '\0' && *p != ' ') {
+		fprintf(stderr,
+"Error calculating length field in ar file %s\n",
 				ar->filename);
 		return RET_ERROR;
 	}
 	ar->next_position += ar->member_size;
-	if( (ar->member_size & 1) != 0 )
+	if ((ar->member_size & 1) != 0)
 		ar->next_position ++;
 
 	/* get the name of the file */
-	if( false ) {
+	if (false) {
 		/* handle long filenames */
 		// TODO!
 	} else {
 		/* normal filenames */
 		int i = sizeof(ar->currentheader.ah_filename);
-		while( i > 0 && ar->currentheader.ah_filename[i-1] == ' ')
+		while (i > 0 && ar->currentheader.ah_filename[i-1] == ' ')
 			i--;
 		/* hop over GNU style filenames, though they should not
 		 * be in a .deb file... */
-		if( i > 0 && ar->currentheader.ah_filename[i-1] == '/' )
+		if (i > 0 && ar->currentheader.ah_filename[i-1] == '/')
 			i--;
-		*filename = strndup(ar->currentheader.ah_filename,i);
+		*filename = strndup(ar->currentheader.ah_filename, i);
 	}
 	ar->compression = c_none;
 	return RET_OK;
@@ -232,18 +238,17 @@ ssize_t ar_archivemember_read(struct archive *a, void *d, const void **p) {
 	struct ar_archive *ar = d;
 	ssize_t bytesread;
 
-	assert( ar->readbuffer != NULL );
-	if( ar->member == NULL )
+	assert (ar->readbuffer != NULL);
+	if (ar->member == NULL)
 		return 0;
 
 	*p = ar->readbuffer;
 	bytesread = uncompress_read(ar->member, ar->readbuffer, BLOCKSIZE);
-	if( bytesread < 0 ) {
-		retvalue r;
+	if (bytesread < 0) {
 		const char *msg;
 		int e;
 
-		r = uncompress_fdclose(ar->member, &e, &msg);
+		(void)uncompress_fdclose(ar->member, &e, &msg);
 		ar->member = NULL;
 		archive_set_error(a, e, msg);
 		return -1;
@@ -257,17 +262,17 @@ int ar_archivemember_open(struct archive *a, void *d) {
 	const char *msg;
 	int e;
 
-	assert( uncompression_supported(ar->compression) );
+	assert (uncompression_supported(ar->compression));
 
-	assert(ar->readbuffer == NULL );
+	assert (ar->readbuffer == NULL);
 	ar->readbuffer = malloc(BLOCKSIZE);
-	if( ar->readbuffer == NULL ) {
+	if (FAILEDTOALLOC(ar->readbuffer)) {
 		archive_set_error(a, ENOMEM, "Out of memory");
 		return ARCHIVE_FATAL;
 	}
 	r = uncompress_fdopen(&ar->member, ar->fd, ar->member_size,
 			ar->compression, &e, &msg);
-	if( RET_IS_OK(r) )
+	if (RET_IS_OK(r))
 		return ARCHIVE_OK;
 	archive_set_error(a, e, msg);
 	return ARCHIVE_FATAL;
@@ -282,12 +287,12 @@ int ar_archivemember_close(UNUSED(struct archive *a), void *d) {
 	free(ar->readbuffer);
 	ar->readbuffer = NULL;
 
-	if( ar->member == NULL )
+	if (ar->member == NULL)
 		return ARCHIVE_OK;
 
 	r = uncompress_fdclose(ar->member, &e, &msg);
 	ar->member = NULL;
-	if( RET_IS_OK(r) )
+	if (RET_IS_OK(r))
 		return ARCHIVE_OK;
 	archive_set_error(a, e, msg);
 	return ARCHIVE_FATAL;
