@@ -66,12 +66,12 @@ static void freeoverridepackage(void *n) {
 void override_free(struct overridefile *info) {
 	struct overridepattern *i;
 
-	if( info == NULL )
+	if (info == NULL)
 		return;
 
 	tdestroy(info->packages, freeoverridepackage);
-	while( (i = info->patterns) != NULL ) {
-		if( i == NULL )
+	while ((i = info->patterns) != NULL) {
+		if (i == NULL)
 			return;
 		strlist_done(&i->data.fields);
 		free(i->pattern);
@@ -82,30 +82,30 @@ void override_free(struct overridefile *info) {
 }
 
 static bool forbidden_field_name(bool source, const char *field) {
-	if( strcasecmp(field, "Package") == 0 )
+	if (strcasecmp(field, "Package") == 0)
 		return true;
-	if( strcasecmp(field, "Version") == 0 )
+	if (strcasecmp(field, "Version") == 0)
 		return true;
-	if( source ) {
-		if( strcasecmp(field, "Files") == 0 )
+	if (source) {
+		if (strcasecmp(field, "Files") == 0)
 			return true;
-		if( strcasecmp(field, "Directory") == 0 )
+		if (strcasecmp(field, "Directory") == 0)
 				return true;
-		if( strcasecmp(field, "Checksums-Sha256") == 0 )
+		if (strcasecmp(field, "Checksums-Sha256") == 0)
 				return true;
-		if( strcasecmp(field, "Checksums-Sha1") == 0 )
+		if (strcasecmp(field, "Checksums-Sha1") == 0)
 				return true;
 		return false;
 	} else {
-		if( strcasecmp(field, "Filename") == 0 )
+		if (strcasecmp(field, "Filename") == 0)
 			return true;
-		if( strcasecmp(field, "MD5sum") == 0 )
+		if (strcasecmp(field, "MD5sum") == 0)
 				return true;
-		if( strcasecmp(field, "SHA1") == 0 )
+		if (strcasecmp(field, "SHA1") == 0)
 				return true;
-		if( strcasecmp(field, "SHA256") == 0 )
+		if (strcasecmp(field, "SHA256") == 0)
 				return true;
-		if( strcasecmp(field, "Size") == 0 )
+		if (strcasecmp(field, "Size") == 0)
 				return true;
 		return false;
 	}
@@ -115,34 +115,34 @@ static retvalue add_override_field(struct overridedata *data, const char *second
 	retvalue r;
 	char *p;
 
-	if( forbidden_field_name(source, secondpart) ) {
+	if (forbidden_field_name(source, secondpart)) {
 		fprintf(stderr,
 "Error: field '%s' not allowed in override files.\n",
 				secondpart);
 		return RET_ERROR;
 	}
-	if( secondpart[0] == '$' ) {
-		if( strcasecmp(secondpart, "$Delete") == 0 ) {
-			if( forbidden_field_name(source, thirdpart) ) {
+	if (secondpart[0] == '$') {
+		if (strcasecmp(secondpart, "$Delete") == 0) {
+			if (forbidden_field_name(source, thirdpart)) {
 				fprintf(stderr,
 "Error: field '%s' not allowed in override files (not even as to be deleted).\n",
 						thirdpart);
 				return RET_ERROR;
 			}
-		} else if( strcasecmp(secondpart, "$Component") != 0 ) {
+		} else if (strcasecmp(secondpart, "$Component") != 0) {
 			fprintf(stderr,
 "Warning: special override field '%s' unknown and will be ignored\n",
 					secondpart);
 		}
 	}
 	p = strdup(secondpart);
-	if( FAILEDTOALLOC(p) )
+	if (FAILEDTOALLOC(p))
 		return RET_ERROR_OOM;
 	r = strlist_add(&data->fields, p);
-	if( RET_WAS_ERROR(r) )
+	if (RET_WAS_ERROR(r))
 		return r;
 	p = strdup(thirdpart);
-	if( FAILEDTOALLOC(p) )
+	if (FAILEDTOALLOC(p))
 		return RET_ERROR_OOM;
 	r = strlist_add(&data->fields, p);
 	return r;
@@ -151,11 +151,11 @@ static retvalue add_override_field(struct overridedata *data, const char *second
 static struct overridepackage *new_package(const char *name) {
 	struct overridepackage *p;
 
-	p = calloc(1, sizeof(struct overridepackage));
-	if( FAILEDTOALLOC(p) )
+	p = zNEW(struct overridepackage);
+	if (FAILEDTOALLOC(p))
 		return NULL;
 	p->packagename = strdup(name);
-	if( FAILEDTOALLOC(p->packagename) ) {
+	if (FAILEDTOALLOC(p->packagename)) {
 		free(p);
 		return NULL;
 	}
@@ -175,29 +175,29 @@ static retvalue add_override(struct overridefile *i, const char *firstpart, cons
 	struct overridepattern *p, **l;
 
 	c = firstpart;
-	while (*c != '\0' && *c != '*' && *c != '[' && *c != '?' )
+	while (*c != '\0' && *c != '*' && *c != '[' && *c != '?')
 		c++;
-	if( *c != '\0' ) {
+	if (*c != '\0') {
 		/* This is a pattern, put into the pattern list */
 		l = &i->patterns;
-		while( (p = *l) != NULL
-				&& strcmp(p->pattern, firstpart) != 0 ) {
+		while ((p = *l) != NULL
+				&& strcmp(p->pattern, firstpart) != 0) {
 			l = &p->next;
 		}
-		if( p == NULL ) {
-			p = calloc(1, sizeof(struct overridepattern));
-			if( FAILEDTOALLOC(p) )
+		if (p == NULL) {
+			p = zNEW(struct overridepattern);
+			if (FAILEDTOALLOC(p))
 				return RET_ERROR_OOM;
 			p->pattern = strdup(firstpart);
-			if( FAILEDTOALLOC(p->pattern) ) {
+			if (FAILEDTOALLOC(p->pattern)) {
 				free(p);
 				return RET_ERROR_OOM;
 			}
 		}
 		r = add_override_field(&p->data,
 				secondpart, thirdpart, source);
-		if( RET_WAS_ERROR(r) ) {
-			if( *l != p ) {
+		if (RET_WAS_ERROR(r)) {
+			if (*l != p) {
 				free(p->pattern);
 				free(p);
 			}
@@ -208,14 +208,14 @@ static retvalue add_override(struct overridefile *i, const char *firstpart, cons
 	}
 
 	pkg = new_package(firstpart);
-	if( FAILEDTOALLOC(pkg) )
+	if (FAILEDTOALLOC(pkg))
 		return RET_ERROR_OOM;
 	node = tsearch(pkg, &i->packages, opackage_compare);
-	if( FAILEDTOALLOC(node) )
+	if (FAILEDTOALLOC(node))
 		return RET_ERROR_OOM;
-	if( *node == pkg ) {
+	if (*node == pkg) {
 		r = strlist_init_n(6, &pkg->data.fields);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 	} else {
 		free(pkg->packagename);
@@ -228,45 +228,45 @@ static retvalue add_override(struct overridefile *i, const char *firstpart, cons
 
 retvalue override_read(const char *filename, struct overridefile **info, bool source) {
 	struct overridefile *i;
-	struct overridepattern **next_pattern;
 	FILE *file;
 	char buffer[1001];
 
-	if( filename == NULL ) {
+	if (filename == NULL) {
 		*info = NULL;
 		return RET_OK;
 	}
-	if( filename[0] != '/' ) {
+	if (filename[0] != '/') {
 		char *fn = calc_conffile(filename);
-		if( fn == NULL )
+		if (FAILEDTOALLOC(fn))
 			return RET_ERROR_OOM;
 		file = fopen(fn, "r");
 		free(fn);
 	} else
-		file = fopen(filename,"r");
+		file = fopen(filename, "r");
 
-	if( file == NULL ) {
+	if (file == NULL) {
 		int e = errno;
 		fprintf(stderr, "Error %d opening override file '%s': %s\n",
 				e, filename, strerror(e));
 		return RET_ERRNO(e);
 	}
-	i = calloc(1, sizeof(struct overridefile));
-	if( FAILEDTOALLOC(i) ) {
+	i = zNEW(struct overridefile);
+	if (FAILEDTOALLOC(i)) {
 		(void)fclose(file);
 		return RET_ERROR_OOM;
 	}
-	next_pattern = &i->patterns;
 
-	while( fgets(buffer,1000,file) != NULL ){
+	while (fgets(buffer, 1000, file) != NULL){
 		retvalue r;
 		const char *firstpart, *secondpart, *thirdpart;
 		char *p;
 		size_t l = strlen(buffer);
 
-		if( buffer[l-1] != '\n' ) {
-			if( l >= 999 ) {
-				fprintf(stderr,"Too long line in '%s'!\n",filename);
+		if (buffer[l-1] != '\n') {
+			if (l >= 999) {
+				fprintf(stderr,
+"Too long line in '%s'!\n",
+						filename);
 				override_free(i);
 				(void)fclose(file);
 				return RET_ERROR;
@@ -277,35 +277,35 @@ retvalue override_read(const char *filename, struct overridefile **info, bool so
 			l--;
 			buffer[l] = '\0';
 		}
-		while( l>0 && xisspace(buffer[l])) {
+		while (l>0 && xisspace(buffer[l])) {
 			buffer[l] = '\0';
 			l--;
 		}
-		if( l== 0 )
+		if (l== 0)
 			continue;
 		p = buffer;
-		while( *p !='\0' && xisspace(*p) )
+		while (*p !='\0' && xisspace(*p))
 			*(p++)='\0';
 		firstpart = p;
-		while( *p !='\0' && !xisspace(*p) )
+		while (*p !='\0' && !xisspace(*p))
 			p++;
-		while( *p !='\0' && xisspace(*p) )
+		while (*p !='\0' && xisspace(*p))
 			*(p++)='\0';
 		secondpart = p;
-		while( *p !='\0' && !xisspace(*p) )
+		while (*p !='\0' && !xisspace(*p))
 			p++;
-		while( *p !='\0' && xisspace(*p) )
+		while (*p !='\0' && xisspace(*p))
 			*(p++)='\0';
 		thirdpart = p;
 		r = add_override(i, firstpart, secondpart, thirdpart, source);
-		if( RET_WAS_ERROR(r) ) {
+		if (RET_WAS_ERROR(r)) {
 			override_free(i);
 			(void)fclose(file);
 			return r;
 		}
 	}
 	(void)fclose(file);
-	if( i->packages != NULL || i->patterns != NULL ) {
+	if (i->packages != NULL || i->patterns != NULL) {
 		*info = i;
 		return RET_OK;
 	} else {
@@ -319,15 +319,15 @@ const struct overridedata *override_search(const struct overridefile *overrides,
 	struct overridepackage pkg, **node;
 	struct overridepattern *p;
 
-	if( overrides == NULL )
+	if (overrides == NULL)
 		return NULL;
 
 	pkg.packagename = (char*)package;
 	node = tfind(&pkg, &overrides->packages, opackage_compare);
-	if( node != NULL && *node != NULL )
+	if (node != NULL && *node != NULL)
 		return &(*node)->data;
-	for( p = overrides->patterns ; p != NULL ; p = p->next ) {
-		if( globmatch(package, p->pattern) )
+	for (p = overrides->patterns ; p != NULL ; p = p->next) {
+		if (globmatch(package, p->pattern))
 			return &p->data;
 	}
 	return NULL;
@@ -336,12 +336,12 @@ const struct overridedata *override_search(const struct overridefile *overrides,
 const char *override_get(const struct overridedata *override, const char *field) {
 	int i;
 
-	if( override == NULL )
+	if (override == NULL)
 		return NULL;
 
-	for( i = 0 ; i+1 < override->fields.count ; i+=2 ) {
+	for (i = 0 ; i+1 < override->fields.count ; i+=2) {
 		// TODO curently case-sensitiv. warn if otherwise?
-		if( strcmp(override->fields.values[i], field) == 0 )
+		if (strcmp(override->fields.values[i], field) == 0)
 			return override->fields.values[i+1];
 	}
 	return NULL;
@@ -353,26 +353,26 @@ const char *override_get(const struct overridedata *override, const char *field)
 struct fieldtoadd *override_addreplacefields(const struct overridedata *override, struct fieldtoadd *otherreplaces) {
 	int i;
 
-	if( override == NULL )
+	if (override == NULL)
 		return otherreplaces;
 
-	for( i = 0 ; i+1 < override->fields.count ; i+=2 ) {
-		if( strcmp(override->fields.values[i],
+	for (i = 0 ; i+1 < override->fields.count ; i+=2) {
+		if (strcmp(override->fields.values[i],
 					SECTION_FIELDNAME) != 0 &&
 				strcmp(override->fields.values[i],
 					PRIORITY_FIELDNAME) != 0 &&
-				override->fields.values[i][0] != '$' ) {
+				override->fields.values[i][0] != '$') {
 			otherreplaces = addfield_new(
 				override->fields.values[i],
 				override->fields.values[i+1],
 				otherreplaces);
-			if( otherreplaces == NULL )
+			if (otherreplaces == NULL)
 				return NULL;
-		} else if( strcasecmp(override->fields.values[i],
-					"$delete") == 0 ) {
+		} else if (strcasecmp(override->fields.values[i],
+					"$delete") == 0) {
 			otherreplaces = deletefield_new(
 				override->fields.values[i+1], otherreplaces);
-			if( otherreplaces == NULL )
+			if (otherreplaces == NULL)
 				return NULL;
 		}
 	}
@@ -384,25 +384,25 @@ retvalue override_allreplacefields(const struct overridedata *override, struct f
 	int i;
 	struct fieldtoadd *fields = NULL;
 
-	assert( override != NULL );
+	assert (override != NULL);
 
-	for( i = 0 ; i+1 < override->fields.count ; i+=2 ) {
-		if( override->fields.values[i][0] != '$' ) {
+	for (i = 0 ; i+1 < override->fields.count ; i+=2) {
+		if (override->fields.values[i][0] != '$') {
 			fields = addfield_new(
 				override->fields.values[i],
 				override->fields.values[i+1],
 				fields);
-			if( fields == NULL )
+			if (FAILEDTOALLOC(fields))
 				return RET_ERROR_OOM;
-		} else if( strcasecmp(override->fields.values[i],
-					"$delete") == 0 ) {
+		} else if (strcasecmp(override->fields.values[i],
+					"$delete") == 0) {
 			fields = deletefield_new(
 				override->fields.values[i+1], fields);
-			if( fields == NULL )
+			if (FAILEDTOALLOC(fields))
 				return RET_ERROR_OOM;
 		}
 	}
-	if( fields == NULL )
+	if (fields == NULL)
 		return RET_NOTHING;
 	*fields_p = fields;
 	return RET_OK;
