@@ -73,32 +73,32 @@ static retvalue split_filekey(const char *filekey, /*@out@*/component_t *compone
 	struct source_node *node;
 	component_t c;
 
-	if( unlikely(memcmp(filekey, "pool/", 5) != 0) )
+	if (unlikely(memcmp(filekey, "pool/", 5) != 0))
 		return RET_NOTHING;
 	filekey += 5;
 	p = strchr(filekey, '/');
-	if( unlikely(p == NULL) )
+	if (unlikely(p == NULL))
 		return RET_NOTHING;
 	c = component_find_l(filekey, (size_t)(p - filekey));
-	if( unlikely(!atom_defined(c)) )
+	if (unlikely(!atom_defined(c)))
 		return RET_NOTHING;
 	p++;
-	if( p[0] != '\0' && p[1] == '/' && p[0] != '/' && p[2] == p[0] ) {
+	if (p[0] != '\0' && p[1] == '/' && p[0] != '/' && p[2] == p[0]) {
 		p += 2;
-		if( unlikely(p[0] == 'l' && p[1] == 'i' && p[2] == 'b') )
+		if (unlikely(p[0] == 'l' && p[1] == 'i' && p[2] == 'b'))
 			return RET_NOTHING;
-	} else if( p[0] == 'l' && p[1] == 'i' && p[2] == 'b' && p[3] != '\0' &&
-			p[4] == '/' && p[5] == 'l' && p[6] == 'i' && p[7] == 'b' &&
-			p[3] != '/' && p[8] == p[3] ) {
+	} else if (p[0] == 'l' && p[1] == 'i' && p[2] == 'b' && p[3] != '\0'
+			&& p[4] == '/' && p[5] == 'l' && p[6] == 'i'
+			&& p[7] == 'b' && p[3] != '/' && p[8] == p[3]) {
 		p += 5;
 	} else
 		return RET_NOTHING;
 	source = p;
 	p = strchr(source, '/');
-	if( unlikely(p == NULL) )
+	if (unlikely(p == NULL))
 		return RET_NOTHING;
 	node = malloc(sizeof(struct source_node) + (p - source) + 1);
-	if( FAILEDTOALLOC(node) )
+	if (FAILEDTOALLOC(node))
 		return RET_ERROR_OOM;
 	node->file_changes = NULL;
 	memcpy(node->sourcename, source, p - source);
@@ -116,12 +116,12 @@ static retvalue remember_name(void **root_p, const char *name, char mode, char m
 	char **p;
 
 	p = tsearch(name - 1, root_p, legacy_compare);
-	if( p == NULL )
+	if (FAILEDTOALLOC(p))
 		return RET_ERROR_OOM;
-	if( *p == name - 1 ) {
+	if (*p == name - 1) {
 		size_t l = strlen(name);
 		*p = malloc(l + 2);
-		if (*p == NULL)
+		if (FAILEDTOALLOC(*p))
 			return RET_ERROR_OOM;
 		**p = mode;
 		memcpy((*p) + 1, name, l + 1);
@@ -139,30 +139,30 @@ static retvalue remember_filekey(const char *filekey, char mode, char mode_and)
 	const char *basefilename IFSTUPIDCC(= NULL);
 
 	r = split_filekey(filekey, &c, &node, &basefilename);
-	if( RET_WAS_ERROR(r) )
+	if (RET_WAS_ERROR(r))
 		return r;
-	if( r == RET_OK ) {
-		assert( atom_defined(c) );
-		if( c > reserved_components ) {
+	if (r == RET_OK) {
+		assert (atom_defined(c));
+		if (c > reserved_components) {
 			void ** h;
 
-			assert( c <= components_count() );
+			assert (c <= components_count());
 
 			h = realloc(file_changes_per_component,
 					sizeof(struct source_node*) * (c + 1));
-			if( FAILEDTOALLOC(h) )
+			if (FAILEDTOALLOC(h))
 				return RET_ERROR_OOM;
 			file_changes_per_component = h;
-			while( reserved_components < c ) {
+			while (reserved_components < c) {
 				h[++reserved_components] = NULL;
 			}
 		}
-		assert( file_changes_per_component != NULL );
+		assert (file_changes_per_component != NULL);
 		found = tsearch(node, &file_changes_per_component[c],
 				source_node_compare);
-		if( FAILEDTOALLOC(found) )
+		if (FAILEDTOALLOC(found))
 			return RET_ERROR_OOM;
-		if( *found != node ) {
+		if (*found != node) {
 			free(node);
 			node = *found;
 		}
@@ -192,44 +192,45 @@ static inline retvalue copyfile(const char *source, const char *destination, int
 	size_t bufsize = 1024*1024;
 
 	buffer = malloc(bufsize);
-	if( FAILEDTOALLOC(buffer) ) {
+	if (FAILEDTOALLOC(buffer)) {
 		(void)close(outfd);
 		(void)unlink(destination);
 		bufsize = 16*1024;
 		buffer = malloc(bufsize);
-		if( FAILEDTOALLOC(buffer) ) {
+		if (FAILEDTOALLOC(buffer))
 			return RET_ERROR_OOM;
-		}
 	}
 
 	infd = open(source, O_RDONLY|O_NOCTTY);
-	if( infd < 0 ) {
+	if (infd < 0) {
 		int en = errno;
 
-		fprintf(stderr, "error %d opening file %s to be copied into the morgue: %s\n",
+		fprintf(stderr,
+"error %d opening file %s to be copied into the morgue: %s\n",
 				en, source, strerror(en));
 		free(buffer);
 		(void)close(outfd);
 		(void)unlink(destination);
 		return RET_ERRNO(en);
 	}
-	while( (readbytes = read(infd, buffer, bufsize)) > 0 ) {
+	while ((readbytes = read(infd, buffer, bufsize)) > 0) {
 		const char *start = buffer;
 
-		if( (off_t)readbytes > length ) {
-			fprintf(stderr, "Mismatch of sizes of '%s': files is larger than expected!\n",
+		if ((off_t)readbytes > length) {
+			fprintf(stderr,
+"Mismatch of sizes of '%s': files is larger than expected!\n",
 					destination);
 			break;
 		}
-		while( readbytes > 0 ) {
+		while (readbytes > 0) {
 			ssize_t written;
 
 			written = write(outfd, start, readbytes);
-			if( written > 0 ) {
-				assert( written <= readbytes );
+			if (written > 0) {
+				assert (written <= readbytes);
 				readbytes -= written;
 				start += written;
-			} else if( written < 0 ) {
+			} else if (written < 0) {
 				int en = errno;
 
 				(void)close(infd);
@@ -237,33 +238,35 @@ static inline retvalue copyfile(const char *source, const char *destination, int
 				(void)unlink(destination);
 				free(buffer);
 
-				fprintf(stderr, "error %d writing to morgue file %s: %s\n",
+				fprintf(stderr,
+"error %d writing to morgue file %s: %s\n",
 						en, destination, strerror(en));
 				return RET_ERRNO(en);
 			}
 		}
 	}
 	free(buffer);
-	if( readbytes == 0 ) {
+	if (readbytes == 0) {
 		err = close(infd);
-		if( err != 0 )
+		if (err != 0)
 			readbytes = -1;
 		infd = -1;
 	}
-	if( readbytes < 0 ) {
+	if (readbytes < 0) {
 		int en = errno;
-		fprintf(stderr, "error %d reading file %s to be copied into the morgue: %s\n",
+		fprintf(stderr,
+"error %d reading file %s to be copied into the morgue: %s\n",
 				en, source, strerror(en));
-		if( infd >= 0 )
+		if (infd >= 0)
 			(void)close(infd);
 		(void)close(outfd);
 		(void)unlink(destination);
 		return RET_ERRNO(en);
 	}
-	if( infd >= 0 )
+	if (infd >= 0)
 		(void)close(infd);
 	err = close(outfd);
-	if( err != 0 ) {
+	if (err != 0) {
 		int en = errno;
 
 		fprintf(stderr, "error %d writing to morgue file %s: %s\n",
@@ -280,50 +283,50 @@ static inline retvalue morgue_name(const char *filekey, char **name_p, int *fd_p
 	int fd, en, number;
 	retvalue r;
 
-	if( FAILEDTOALLOC(firsttry) )
+	if (FAILEDTOALLOC(firsttry))
 		return RET_ERROR_OOM;
 
 	fd = open(firsttry, O_WRONLY|O_CREAT|O_EXCL|O_NOCTTY, 0666);
-	if( fd >= 0 ) {
-		assert( fd > 2 );
+	if (fd >= 0) {
+		assert (fd > 2);
 		*name_p = firsttry;
 		*fd_p = fd;
 		return RET_OK;
 	}
 	en = errno;
-	if( en == ENOENT ) {
+	if (en == ENOENT) {
 		r = dirs_make_recursive(global.morguedir);
-		if( RET_WAS_ERROR(r) ) {
+		if (RET_WAS_ERROR(r)) {
 			free(firsttry);
 			return r;
 		}
 		/* try again */
 		fd = open(firsttry, O_WRONLY|O_CREAT|O_EXCL|O_NOCTTY, 0666);
-		if( fd >= 0 ) {
-			assert( fd > 2 );
+		if (fd >= 0) {
+			assert (fd > 2);
 			*name_p = firsttry;
 			*fd_p = fd;
 			return RET_OK;
 		}
 		en = errno;
 	}
-	if( en != EEXIST ) {
+	if (en != EEXIST) {
 		fprintf(stderr, "error %d creating morgue-file %s: %s\n",
 				en, firsttry, strerror(en));
 		free(firsttry);
 		return RET_ERRNO(en);
 	}
 	/* file exists, try names with -number appended: */
-	for( number = 1 ; number < 1000 ; number++ ) {
+	for (number = 1 ; number < 1000 ; number++) {
 		char *try = mprintf("%s-%d", firsttry, number);
 
-		if( FAILEDTOALLOC(try) ) {
+		if (FAILEDTOALLOC(try)) {
 			free(firsttry);
 			return RET_ERROR_OOM;
 		}
 		fd = open(try, O_WRONLY|O_CREAT|O_EXCL|O_NOCTTY, 0666);
-		if( fd >= 0 ) {
-			assert( fd > 2 );
+		if (fd >= 0) {
+			assert (fd > 2);
 			free(firsttry);
 			*name_p = try;
 			*fd_p = fd;
@@ -343,51 +346,54 @@ static inline retvalue movefiletomorgue(const char *filekey, const char *filenam
 	int err;
 	retvalue r;
 
-	if( !new && global.morguedir != NULL ) {
+	if (!new && global.morguedir != NULL) {
 		int morguefd = -1;
 		struct stat s;
 
-	       	r = morgue_name(filekey, &morguefilename, &morguefd);
-		assert( r != RET_NOTHING );
-		if( RET_WAS_ERROR(r) )
+		r = morgue_name(filekey, &morguefilename, &morguefd);
+		assert (r != RET_NOTHING);
+		if (RET_WAS_ERROR(r))
 			return r;
 		err = lstat(filename, &s);
-		if( err != 0 ) {
+		if (err != 0) {
 			int en = errno;
-			if( errno == ENOENT ) {
+			if (errno == ENOENT) {
 				(void)close(morguefd);
 				(void)unlink(morguefilename);
 				free(morguefilename);
 				return RET_NOTHING;
 			}
-			fprintf(stderr, "error %d looking at file %s to be moved into the morgue: %s\n",
+			fprintf(stderr,
+"error %d looking at file %s to be moved into the morgue: %s\n",
 					en, filename, strerror(en));
 			(void)close(morguefd);
 			(void)unlink(morguefilename);
 			free(morguefilename);
 			return RET_ERRNO(en);
 		}
-		if( S_ISLNK(s.st_mode) ) {
+		if (S_ISLNK(s.st_mode)) {
 			/* no need to copy a symbolic link: */
 			(void)close(morguefd);
 			(void)unlink(morguefilename);
 			free(morguefilename);
 			morguefilename = NULL;
-		} else if( S_ISREG(s.st_mode) ) {
+		} else if (S_ISREG(s.st_mode)) {
 			err = rename(filename, morguefilename);
-			if( err == 0 ) {
+			if (err == 0) {
 				(void)close(morguefd);
 				free(morguefilename);
 				return RET_OK;
 			}
 			r = copyfile(filename, morguefilename, morguefd,
 				       s.st_size);
-			if( RET_WAS_ERROR(r) ) {
+			if (RET_WAS_ERROR(r)) {
 				free(morguefilename);
 				return r;
 			}
 		} else {
-			fprintf(stderr, "Strange (non-regular) file '%s' in the pool.\nPlease delete manually!\n", filename);
+			fprintf(stderr,
+"Strange (non-regular) file '%s' in the pool.\nPlease delete manually!\n",
+					filename);
 			(void)close(morguefd);
 			(void)unlink(morguefilename);
 			free(morguefilename);
@@ -396,13 +402,13 @@ static inline retvalue movefiletomorgue(const char *filekey, const char *filenam
 		}
 	}
 	err = unlink(filename);
-	if( err != 0 ) {
+	if (err != 0) {
 		int en = errno;
-		if( errno == ENOENT )
+		if (errno == ENOENT)
 			return RET_NOTHING;
 		fprintf(stderr, "error %d while unlinking %s: %s\n",
 			en, filename, strerror(en));
-		if( morguefilename != NULL ) {
+		if (morguefilename != NULL) {
 			(void)unlink(morguefilename);
 			free(morguefilename);
 		}
@@ -419,43 +425,45 @@ static retvalue deletepoolfile(const char *filekey, bool new) {
 	char *filename;
 	retvalue r;
 
-	if( interrupted() )
+	if (interrupted())
 		return RET_ERROR_INTERRUPTED;
 	filename = files_calcfullfilename(filekey);
-	if( filename == NULL )
+	if (FAILEDTOALLOC(filename))
 		return RET_ERROR_OOM;
 	/* move to morgue or simply delete: */
 	r = movefiletomorgue(filekey, filename, new);
-	if( r == RET_NOTHING ) {
+	if (r == RET_NOTHING) {
 		fprintf(stderr, "%s not found, forgetting anyway\n", filename);
 	}
-	if( !RET_IS_OK(r) ) {
+	if (!RET_IS_OK(r)) {
 		free(filename);
 		return r;
 	}
-	if( !global.keepdirectories ) {
+	if (!global.keepdirectories) {
 		/* try to delete parent directories, until one gives
 		 * errors (hopefully because it still contains files) */
 		size_t fixedpartlen = strlen(global.outdir);
 		char *p;
 		int err, en;
 
-		while( (p = strrchr(filename,'/')) != NULL ) {
+		while ((p = strrchr(filename, '/')) != NULL) {
 			/* do not try to remove parts of the mirrordir */
-			if( (size_t)(p-filename) <= fixedpartlen+1 )
+			if ((size_t)(p-filename) <= fixedpartlen+1)
 				break;
 			*p ='\0';
 			/* try to rmdir the directory, this will
 			 * fail if there are still other files or directories
 			 * in it: */
 			err = rmdir(filename);
-			if( err == 0 ) {
-				if( verbose > 1 ) {
-					printf("removed now empty directory %s\n",filename);
+			if (err == 0) {
+				if (verbose > 1) {
+					printf(
+"removed now empty directory %s\n",
+							filename);
 				}
 			} else {
 				en = errno;
-				if( en != ENOTEMPTY ) {
+				if (en != ENOTEMPTY) {
 					//TODO: check here if only some
 					//other error was first and it
 					//is not empty so we do not have
@@ -476,17 +484,17 @@ static retvalue deletepoolfile(const char *filekey, bool new) {
 }
 
 
-retvalue pool_delete(struct database *database, const char *filekey) {
+retvalue pool_delete(const char *filekey) {
 	retvalue r;
 
-	if( verbose >= 1 )
-		printf("deleting and forgetting %s\n",filekey);
+	if (verbose >= 1)
+		printf("deleting and forgetting %s\n", filekey);
 
 	r = deletepoolfile(filekey, false);
-	if( RET_WAS_ERROR(r) )
+	if (RET_WAS_ERROR(r))
 		return r;
 
-	return files_remove(database, filekey);
+	return files_remove(filekey);
 }
 
 /* called from files_remove: */
@@ -497,7 +505,6 @@ retvalue pool_markdeleted(const char *filekey) {
 
 /* libc's twalk misses a callback_data pointer, so we need some temporary
  * global variables: */
-static struct database *d;
 static retvalue result;
 static bool first, onlycount;
 static long woulddelete_count;
@@ -508,39 +515,39 @@ static void removeifunreferenced(const void *nodep, const VISIT which, UNUSED(co
 	char *node; const char *filekey;
 	retvalue r;
 
-	if( which != leaf && which != postorder)
+	if (which != leaf && which != postorder)
 		return;
 
-	if( interrupted() )
+	if (interrupted())
 		return;
 
 	node = *(char **)nodep;
 	filekey = node + 1;
-	if( (*node & pl_UNREFERENCED) == 0 )
+	if ((*node & pl_UNREFERENCED) == 0)
 		return;
-	r = references_isused(d, filekey);
-	if( r != RET_NOTHING )
+	r = references_isused(filekey);
+	if (r != RET_NOTHING)
 		return;
 
-	if( onlycount ) {
+	if (onlycount) {
 		woulddelete_count++;
 		return;
 	}
 
-	if( verbose >= 0 && first ) {
+	if (verbose >= 0 && first) {
 		printf("Deleting files no longer referenced...\n");
 		first = false;
 	}
-	if( verbose >= 1 )
+	if (verbose >= 1)
 		printf("deleting and forgetting %s\n", filekey);
 	r = deletepoolfile(filekey, (*node & pl_ADDED) != 0);
 	RET_UPDATE(result, r);
-	if( !RET_WAS_ERROR(r) ) {
-		r = files_removesilent(d, filekey);
+	if (!RET_WAS_ERROR(r)) {
+		r = files_removesilent(filekey);
 		RET_UPDATE(result, r);
-		if( !RET_WAS_ERROR(r) )
+		if (!RET_WAS_ERROR(r))
 			*node &= ~pl_UNREFERENCED;
-		if( RET_IS_OK(r) )
+		if (RET_IS_OK(r))
 			*node |= pl_DELETED;
 	}
 }
@@ -551,40 +558,40 @@ static void removeifunreferenced2(const void *nodep, const VISIT which, UNUSED(c
 	char *filekey;
 	retvalue r;
 
-	if( which != leaf && which != postorder)
+	if (which != leaf && which != postorder)
 		return;
 
-	if( interrupted() )
+	if (interrupted())
 		return;
 
 	node = *(char **)nodep;
-	if( (*node & pl_UNREFERENCED) == 0 )
+	if ((*node & pl_UNREFERENCED) == 0)
 		return;
 	filekey = calc_filekey(current_component, sourcename, node + 1);
-	r = references_isused(d, filekey);
-	if( r != RET_NOTHING ) {
+	r = references_isused(filekey);
+	if (r != RET_NOTHING) {
 		free(filekey);
 		return;
 	}
-	if( onlycount ) {
+	if (onlycount) {
 		woulddelete_count++;
 		free(filekey);
 		return;
 	}
-	if( verbose >= 0 && first ) {
+	if (verbose >= 0 && first) {
 		printf("Deleting files no longer referenced...\n");
 		first = false;
 	}
-	if( verbose >= 1 )
+	if (verbose >= 1)
 		printf("deleting and forgetting %s\n", filekey);
 	r = deletepoolfile(filekey, (*node & pl_ADDED) != 0);
 	RET_UPDATE(result, r);
-	if( !RET_WAS_ERROR(r) ) {
-		r = files_removesilent(d, filekey);
+	if (!RET_WAS_ERROR(r)) {
+		r = files_removesilent(filekey);
 		RET_UPDATE(result, r);
-		if( !RET_WAS_ERROR(r) )
+		if (!RET_WAS_ERROR(r))
 			*node &= ~pl_UNREFERENCED;
-		if( RET_IS_OK(r) )
+		if (RET_IS_OK(r))
 			*node |= pl_DELETED;
 	}
 	RET_UPDATE(result, r);
@@ -594,10 +601,10 @@ static void removeifunreferenced2(const void *nodep, const VISIT which, UNUSED(c
 static void removeunreferenced_from_component(const void *nodep, const VISIT which, UNUSED(const int depth)) {
 	struct source_node *node;
 
-	if( which != leaf && which != postorder)
+	if (which != leaf && which != postorder)
 		return;
 
-	if( interrupted() )
+	if (interrupted())
 		return;
 
 	node = *(struct source_node **)nodep;
@@ -605,28 +612,26 @@ static void removeunreferenced_from_component(const void *nodep, const VISIT whi
 	twalk(node->file_changes, removeifunreferenced2);
 }
 
-retvalue pool_removeunreferenced(struct database *database, bool delete) {
+retvalue pool_removeunreferenced(bool delete) {
 	component_t c;
 
-	if( !delete && verbose <= 0 )
+	if (!delete && verbose <= 0)
 		return RET_NOTHING;
 
-	d = database;
 	result = RET_NOTHING;
 	first = true;
 	onlycount = !delete;
 	woulddelete_count = 0;
-	for( c = 1 ; c <= reserved_components ; c++ ) {
-		assert( file_changes_per_component != NULL );
+	for (c = 1 ; c <= reserved_components ; c++) {
+		assert (file_changes_per_component != NULL);
 		current_component = c;
 		twalk(file_changes_per_component[c],
 				removeunreferenced_from_component);
 	}
 	twalk(legacy_file_changes, removeifunreferenced);
-	d = NULL;
-	if( interrupted() )
+	if (interrupted())
 		result = RET_ERROR_INTERRUPTED;
-	if( !delete && woulddelete_count > 0 ) {
+	if (!delete && woulddelete_count > 0) {
 		printf(
 "%lu files lost their last reference.\n"
 "(dumpunreferenced lists such files, use deleteunreferenced to delete them.)\n",
@@ -639,42 +644,44 @@ static void removeunusednew(const void *nodep, const VISIT which, UNUSED(const i
 	char *node; const char *filekey;
 	retvalue r;
 
-	if( which != leaf && which != postorder)
+	if (which != leaf && which != postorder)
 		return;
 
-	if( interrupted() )
+	if (interrupted())
 		return;
 
 	node = *(char **)nodep;
 	filekey = node + 1;
 	/* only look at newly added and not already deleted */
-	if( (*node & (pl_ADDED|pl_DELETED)) != pl_ADDED )
+	if ((*node & (pl_ADDED|pl_DELETED)) != pl_ADDED)
 		return;
-	r = references_isused(d, filekey);
-	if( r != RET_NOTHING )
+	r = references_isused(filekey);
+	if (r != RET_NOTHING)
 		return;
 
-	if( onlycount ) {
+	if (onlycount) {
 		woulddelete_count++;
 		return;
 	}
 
-	if( verbose >= 0 && first ) {
-		printf("Deleting files just added to the pool but not used (to avoid use --keepunusednewfiles next time)\n");
+	if (verbose >= 0 && first) {
+		printf(
+"Deleting files just added to the pool but not used.\n"
+"(to avoid use --keepunusednewfiles next time)\n");
 		first = false;
 	}
-	if( verbose >= 1 )
+	if (verbose >= 1)
 		printf("deleting and forgetting %s\n", filekey);
 	r = deletepoolfile(filekey, true);
 	RET_UPDATE(result, r);
-	if( !RET_WAS_ERROR(r) ) {
-		r = files_removesilent(d, filekey);
+	if (!RET_WAS_ERROR(r)) {
+		r = files_removesilent(filekey);
 		RET_UPDATE(result, r);
 		/* don't remove pl_ADDED here, otherwise the hook
 		 * script will be told to remove something not added */
-		if( !RET_WAS_ERROR(r) )
+		if (!RET_WAS_ERROR(r))
 			*node &= ~pl_UNREFERENCED;
-		if( RET_IS_OK(r) )
+		if (RET_IS_OK(r))
 			*node |= pl_DELETED;
 	}
 }
@@ -685,43 +692,45 @@ static void removeunusednew2(const void *nodep, const VISIT which, UNUSED(const
 	char *filekey;
 	retvalue r;
 
-	if( which != leaf && which != postorder)
+	if (which != leaf && which != postorder)
 		return;
 
-	if( interrupted() )
+	if (interrupted())
 		return;
 
 	node = *(char **)nodep;
 	/* only look at newly added and not already deleted */
-	if( (*node & (pl_ADDED|pl_DELETED)) != pl_ADDED )
+	if ((*node & (pl_ADDED|pl_DELETED)) != pl_ADDED)
 		return;
 	filekey = calc_filekey(current_component, sourcename, node + 1);
-	r = references_isused(d, filekey);
-	if( r != RET_NOTHING ) {
+	r = references_isused(filekey);
+	if (r != RET_NOTHING) {
 		free(filekey);
 		return;
 	}
-	if( onlycount ) {
+	if (onlycount) {
 		woulddelete_count++;
 		free(filekey);
 		return;
 	}
-	if( verbose >= 0 && first ) {
-		printf("Deleting files just added to the pool but not used (to avoid use --keepunusednewfiles next time)\n");
+	if (verbose >= 0 && first) {
+		printf(
+"Deleting files just added to the pool but not used.\n"
+"(to avoid use --keepunusednewfiles next time)\n");
 		first = false;
 	}
-	if( verbose >= 1 )
+	if (verbose >= 1)
 		printf("deleting and forgetting %s\n", filekey);
 	r = deletepoolfile(filekey, true);
 	RET_UPDATE(result, r);
-	if( !RET_WAS_ERROR(r) ) {
-		r = files_removesilent(d, filekey);
+	if (!RET_WAS_ERROR(r)) {
+		r = files_removesilent(filekey);
 		RET_UPDATE(result, r);
 		/* don't remove pl_ADDED here, otherwise the hook
 		 * script will be told to remove something not added */
-		if( !RET_WAS_ERROR(r) )
+		if (!RET_WAS_ERROR(r))
 			*node &= ~pl_UNREFERENCED;
-		if( RET_IS_OK(r) )
+		if (RET_IS_OK(r))
 			*node |= pl_DELETED;
 	}
 	RET_UPDATE(result, r);
@@ -731,10 +740,10 @@ static void removeunusednew2(const void *nodep, const VISIT which, UNUSED(const
 static void removeunusednew_from_component(const void *nodep, const VISIT which, UNUSED(const int depth)) {
 	struct source_node *node;
 
-	if( which != leaf && which != postorder)
+	if (which != leaf && which != postorder)
 		return;
 
-	if( interrupted() )
+	if (interrupted())
 		return;
 
 	node = *(struct source_node **)nodep;
@@ -742,27 +751,25 @@ static void removeunusednew_from_component(const void *nodep, const VISIT which,
 	twalk(node->file_changes, removeunusednew2);
 }
 
-void pool_tidyadded(struct database *database, bool delete) {
+void pool_tidyadded(bool delete) {
 	component_t c;
 
-	if( !delete && verbose < 0 )
+	if (!delete && verbose < 0)
 		return;
 
-	d = database;
 	result = RET_NOTHING;
 	first = true;
 	onlycount = !delete;
 	woulddelete_count = 0;
-	for( c = 1 ; c <= reserved_components ; c++ ) {
-		assert( file_changes_per_component != NULL );
+	for (c = 1 ; c <= reserved_components ; c++) {
+		assert (file_changes_per_component != NULL);
 		current_component = c;
 		twalk(file_changes_per_component[c],
 				removeunusednew_from_component);
 	}
 	// this should not really happen at all, but better safe then sorry:
 	twalk(legacy_file_changes, removeunusednew);
-	d = NULL;
-	if( !delete && woulddelete_count > 0 ) {
+	if (!delete && woulddelete_count > 0) {
 		printf(
 "%lu files were added but not used.\n"
 "The next deleteunreferenced call will delete them.\n",
