@@ -17,12 +17,12 @@ retvalue pool_markadded(const char *);
 retvalue pool_markdeleted(const char *);
 
 /* Remove all files that lost their last reference, or only count them */
-retvalue pool_removeunreferenced(struct database *, bool delete);
+retvalue pool_removeunreferenced(bool delete);
 
 /* Delete all added files that are not used, or only count them */
-void pool_tidyadded(struct database*, bool deletenew);
+void pool_tidyadded(bool deletenew);
 
 /* delete and forget a single file */
-retvalue pool_delete(struct database *, const char *);
+retvalue pool_delete(const char *);
 
 #endif
