@@ -62,13 +62,14 @@ struct pull_rule {
 	// NULL means no condition
 	/*@null@*/term *includecondition;
 	struct filterlist filterlist;
+	struct filterlist filtersrclist;
 	/*----only set after _addsourcedistribution----*/
 	/*@NULL@*/ struct distribution *distribution;
 	bool used;
 };
 
 static void pull_rule_free(/*@only@*/struct pull_rule *pull) {
-	if( pull == NULL )
+	if (pull == NULL)
 		return;
 	free(pull->name);
 	free(pull->from);
@@ -78,11 +79,12 @@ static void pull_rule_free(/*@only@*/struct pull_rule *pull) {
 	atomlist_done(&pull->udebcomponents);
 	term_free(pull->includecondition);
 	filterlist_release(&pull->filterlist);
+	filterlist_release(&pull->filtersrclist);
 	free(pull);
 }
 
 void pull_freerules(struct pull_rule *p) {
-	while( p != NULL ) {
+	while (p != NULL) {
 		struct pull_rule *rule;
 
 		rule = p;
@@ -97,6 +99,7 @@ CFvalueSETPROC(pull_rule, from)
 CFatomlistSETPROC(pull_rule, components, at_component)
 CFatomlistSETPROC(pull_rule, udebcomponents, at_component)
 CFfilterlistSETPROC(pull_rule, filterlist)
+CFfilterlistSETPROC(pull_rule, filtersrclist)
 CFtermSETPROC(pull_rule, includecondition)
 
 CFUSETPROC(pull_rule, architectures) {
@@ -108,7 +111,7 @@ CFUSETPROC(pull_rule, architectures) {
 			at_architecture,
 			&this->architectures_from,
 			&this->architectures_into);
-	if( r == RET_NOTHING ) {
+	if (r == RET_NOTHING) {
 		fprintf(stderr,
 "Warning parsing %s, line %u: an empty Architectures field\n"
 "causes the whole rule to do nothing.\n",
@@ -125,6 +128,7 @@ static const struct configfield pullconfigfields[] = {
 	CF("Components", pull_rule, components),
 	CF("UDebComponents", pull_rule, udebcomponents),
 	CF("FilterFormula", pull_rule, includecondition),
+	CF("FilterSrcList", pull_rule, filtersrclist),
 	CF("FilterList", pull_rule, filterlist)
 };
 
@@ -135,10 +139,10 @@ retvalue pull_getrules(struct pull_rule **rules) {
 	r = configfile_parse("pulls", IGNORABLE(unknownfield),
 			configparser_pull_rule_init, linkedlistfinish,
 			pullconfigfields, ARRAYCOUNT(pullconfigfields), &pull);
-	if( RET_IS_OK(r) )
+	if (RET_IS_OK(r))
 		*rules = pull;
-	else if( r == RET_NOTHING ) {
-		assert( pull == NULL );
+	else if (r == RET_NOTHING) {
+		assert (pull == NULL);
 		*rules = NULL;
 		r = RET_OK;
 	} else {
@@ -165,7 +169,7 @@ struct pull_distribution {
 };
 
 void pull_freedistributions(struct pull_distribution *d) {
-	while( d != NULL ) {
+	while (d != NULL) {
 		struct pull_distribution *next;
 
 		next = d->next;
@@ -182,25 +186,25 @@ static retvalue pull_initdistribution(struct pull_distribution **pp,
 	int i;
 
 	assert(distribution != NULL);
-	if( distribution->pulls.count == 0 )
+	if (distribution->pulls.count == 0)
 		return RET_NOTHING;
 
 	p = malloc(sizeof(struct pull_distribution)+
 		sizeof(struct pull_rules *)*distribution->pulls.count);
-	if( p == NULL )
+	if (FAILEDTOALLOC(p))
 		return RET_ERROR_OOM;
 	p->next = NULL;
 	p->distribution = distribution;
 	p->targets = NULL;
-	for( i = 0 ; i < distribution->pulls.count ; i++ ) {
+	for (i = 0 ; i < distribution->pulls.count ; i++) {
 		const char *name = distribution->pulls.values[i];
-		if( strcmp(name,"-") == 0 ) {
+		if (strcmp(name, "-") == 0) {
 			p->rules[i] = NULL;
 		} else {
 			struct pull_rule *rule = rules;
-			while( rule && strcmp(rule->name,name) != 0 )
+			while (rule && strcmp(rule->name, name) != 0)
 				rule = rule->next;
-			if( rule == NULL ) {
+			if (rule == NULL) {
 				fprintf(stderr,
 "Error: Unknown pull rule '%s' in distribution '%s'!\n",
 						name, distribution->codename);
@@ -222,16 +226,16 @@ static retvalue pull_init(struct pull_distribution **pulls,
 	struct distribution *d;
 	retvalue r;
 
-	for( d = distributions ; d != NULL ; d = d->next ) {
-		if( !d->selected )
+	for (d = distributions ; d != NULL ; d = d->next) {
+		if (!d->selected)
 			continue;
 		r = pull_initdistribution(pp, d, rules);
-		if( RET_WAS_ERROR(r) ) {
+		if (RET_WAS_ERROR(r)) {
 			pull_freedistributions(p);
 			return r;
 		}
-		if( RET_IS_OK(r) ) {
-			assert( *pp != NULL );
+		if (RET_IS_OK(r)) {
+			assert (*pp != NULL);
 			pp = &(*pp)->next;
 		}
 	}
@@ -248,16 +252,17 @@ static retvalue pull_loadsourcedistributions(struct distribution *alldistributio
 	struct pull_rule *rule;
 	struct distribution *d;
 
-	for( rule = rules ; rule != NULL ; rule = rule->next ) {
-		if( rule->used && rule->distribution == NULL ) {
-			for( d = alldistributions ; d != NULL ; d = d->next ) {
-				if( strcmp(d->codename, rule->from) == 0 ) {
+	for (rule = rules ; rule != NULL ; rule = rule->next) {
+		if (rule->used && rule->distribution == NULL) {
+			for (d = alldistributions ; d != NULL ; d = d->next) {
+				if (strcmp(d->codename, rule->from) == 0) {
 					rule->distribution = d;
 					break;
 				}
 			}
-			if( d == NULL ) {
-				fprintf(stderr, "Error: Unknown distribution '%s' referenced in pull rule '%s'\n",
+			if (d == NULL) {
+				fprintf(stderr,
+"Error: Unknown distribution '%s' referenced in pull rule '%s'\n",
 						rule->from, rule->name);
 				return RET_ERROR_MISSING;
 			}
@@ -285,10 +290,10 @@ struct pull_target {
 };
 
 static void pull_freetargets(struct pull_target *targets) {
-	while( targets != NULL ) {
+	while (targets != NULL) {
 		struct pull_target *target = targets;
 		targets = target->next;
-		while( target->sources != NULL ) {
+		while (target->sources != NULL) {
 			struct pull_source *source = target->sources;
 			target->sources = source->next;
 			free(source);
@@ -304,47 +309,47 @@ static retvalue pull_createsource(struct pull_rule *rule,
 	const struct atomlist *a_from, *a_into;
 	int ai;
 
-	assert( rule != NULL );
-	assert( rule->distribution != NULL );
+	assert (rule != NULL);
+	assert (rule->distribution != NULL);
 
-	if( rule->architectures_set ) {
+	if (rule->architectures_set) {
 		a_from = &rule->architectures_from;
 		a_into = &rule->architectures_into;
 	} else {
 		a_from = &rule->distribution->architectures;
 		a_into = &rule->distribution->architectures;
 	}
-	if( target->packagetype_atom == pt_udeb )  {
-		if( rule->udebcomponents_set )
+	if (target->packagetype == pt_udeb)  {
+		if (rule->udebcomponents_set)
 			c = &rule->udebcomponents;
 		else
 			c = &rule->distribution->udebcomponents;
 	} else {
-		if( rule->components_set )
+		if (rule->components_set)
 			c = &rule->components;
 		else
 			c = &rule->distribution->components;
 	}
 
-	if( !atomlist_in(c, target->component_atom) )
+	if (!atomlist_in(c, target->component))
 		return RET_NOTHING;
 
-	for( ai = 0 ; ai < a_into->count ; ai++ ) {
+	for (ai = 0 ; ai < a_into->count ; ai++) {
 		struct pull_source *source;
 
-		if( a_into->atoms[ai] != target->architecture_atom )
+		if (a_into->atoms[ai] != target->architecture)
 			continue;
 
-		source = malloc(sizeof(struct pull_source));
-		if( source == NULL )
+		source = NEW(struct pull_source);
+		if (FAILEDTOALLOC(source))
 			return RET_ERROR_OOM;
 
 		source->next = NULL;
 		source->rule = rule;
 		source->source = distribution_getpart(rule->distribution,
-				target->component_atom,
+				target->component,
 				a_from->atoms[ai],
-				target->packagetype_atom);
+				target->packagetype);
 		**s = source;
 		*s = &source->next;
 	}
@@ -354,8 +359,8 @@ static retvalue pull_createsource(struct pull_rule *rule,
 static retvalue pull_createdelete(struct pull_source ***s) {
 	struct pull_source *source;
 
-	source = malloc(sizeof(struct pull_source));
-	if( source == NULL )
+	source = NEW(struct pull_source);
+	if (FAILEDTOALLOC(source))
 		return RET_ERROR_OOM;
 
 	source->next =  NULL;
@@ -372,10 +377,9 @@ static retvalue generatepulltarget(struct pull_distribution *pd, struct target *
 	retvalue r;
 	int i;
 
-	pt = malloc(sizeof(struct pull_target));
-	if( pt == NULL ) {
+	pt = NEW(struct pull_target);
+	if (FAILEDTOALLOC(pt))
 		return RET_ERROR_OOM;
-	}
 	pt->target = target;
 	pt->next = pd->targets;
 	pt->upgradelist = NULL;
@@ -383,14 +387,14 @@ static retvalue generatepulltarget(struct pull_distribution *pd, struct target *
 	s = &pt->sources;
 	pd->targets = pt;
 
-	for( i = 0 ; i < pd->distribution->pulls.count ; i++ ) {
+	for (i = 0 ; i < pd->distribution->pulls.count ; i++) {
 		struct pull_rule *rule = pd->rules[i];
 
-		if( rule == NULL)
+		if (rule == NULL)
 			r = pull_createdelete(&s);
 		else
 			r = pull_createsource(rule, target, &s);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 	}
 
@@ -400,17 +404,14 @@ static retvalue generatepulltarget(struct pull_distribution *pd, struct target *
 static retvalue pull_generatetargets(struct pull_distribution *pull_distributions) {
 	struct pull_distribution *pd;
 	struct target *target;
-	struct pull_distribution *u_ds;
 	retvalue r;
 
-	u_ds = NULL;
-
-	for( pd = pull_distributions ; pd != NULL ; pd = pd->next ) {
-		for( target = pd->distribution->targets ; target != NULL ;
+	for (pd = pull_distributions ; pd != NULL ; pd = pd->next) {
+		for (target = pd->distribution->targets ; target != NULL ;
 				target = target->next) {
 
-			r = generatepulltarget(pd,target);
-			if( RET_WAS_ERROR(r) )
+			r = generatepulltarget(pd, target);
+			if (RET_WAS_ERROR(r))
 				return r;
 		}
 	}
@@ -425,14 +426,14 @@ static bool *preparefoundlist(const struct atomlist *list) {
 	bool *found;
 	int i, j;
 
-	found = calloc(list->count, sizeof(bool));
-	if( found == NULL )
+	found = nzNEW(list->count, bool);
+	if (FAILEDTOALLOC(found))
 		return found;
-	for( i = 0 ; i < list->count ; i++ ) {
-		if( found[i] )
+	for (i = 0 ; i < list->count ; i++) {
+		if (found[i])
 			continue;
-		for( j = i + 1 ; j < list->count ; j++ )
-			if( list->atoms[i] == list->atoms[j] )
+		for (j = i + 1 ; j < list->count ; j++)
+			if (list->atoms[i] == list->atoms[j])
 				found[j] = true;
 	}
 	return found;
@@ -442,12 +443,12 @@ static bool *preparefoundlist(const struct atomlist *list) {
 static inline void markasused(const struct strlist *pulls, const char *rulename, const struct atomlist *needed, const struct atomlist *have, bool *found) {
 	int i, j, o;
 
-	for( i = 0 ; i < pulls->count ; i++ ) {
-		if( strcmp(pulls->values[i], rulename) != 0 )
+	for (i = 0 ; i < pulls->count ; i++) {
+		if (strcmp(pulls->values[i], rulename) != 0)
 			continue;
-		for( j = 0 ; j < have->count ; j++ ) {
+		for (j = 0 ; j < have->count ; j++) {
 			o = atomlist_ofs(needed, have->atoms[j]);
-			if( o >= 0 )
+			if (o >= 0)
 				found[o] = true;
 		}
 	}
@@ -458,19 +459,19 @@ static void checkifarchitectureisused(const struct atomlist *architectures, cons
 	const struct distribution *d;
 	int i;
 
-	assert( rule != NULL );
-	if( architectures->count == 0 )
+	assert (rule != NULL);
+	if (architectures->count == 0)
 		return;
 	found = preparefoundlist(architectures);
-	if( found == NULL )
+	if (found == NULL)
 		return;
-	for( d = alldistributions ; d != NULL ; d = d->next ) {
+	for (d = alldistributions ; d != NULL ; d = d->next) {
 		markasused(&d->pulls, rule->name,
 				architectures, &d->architectures,
 				found);
 	}
-	for( i = 0 ; i < architectures->count ; i++ ) {
-		if( found[i] )
+	for (i = 0 ; i < architectures->count ; i++) {
+		if (found[i])
 			continue;
 		fprintf(stderr,
 "Warning: pull rule '%s' wants to %s architecture '%s',\n"
@@ -488,19 +489,19 @@ static void checkifcomponentisused(const struct atomlist *components, const stru
 	const struct distribution *d;
 	int i;
 
-	assert( rule != NULL );
-	if( components->count == 0 )
+	assert (rule != NULL);
+	if (components->count == 0)
 		return;
 	found = preparefoundlist(components);
-	if( found == NULL )
+	if (found == NULL)
 		return;
-	for( d = alldistributions ; d != NULL ; d = d->next ) {
+	for (d = alldistributions ; d != NULL ; d = d->next) {
 		markasused(&d->pulls, rule->name,
 				components, &d->components,
 				found);
 	}
-	for( i = 0 ; i < components->count ; i++ ) {
-		if( found[i] )
+	for (i = 0 ; i < components->count ; i++) {
+		if (found[i])
 			continue;
 		fprintf(stderr,
 "Warning: pull rule '%s' wants to %s component '%s',\n"
@@ -518,19 +519,19 @@ static void checkifudebcomponentisused(const struct atomlist *udebcomponents, co
 	const struct distribution *d;
 	int i;
 
-	assert( rule != NULL );
-	if( udebcomponents->count == 0 )
+	assert (rule != NULL);
+	if (udebcomponents->count == 0)
 		return;
 	found = preparefoundlist(udebcomponents);
-	if( found == NULL )
+	if (found == NULL)
 		return;
-	for( d = alldistributions ; d != NULL ; d = d->next ) {
+	for (d = alldistributions ; d != NULL ; d = d->next) {
 		markasused(&d->pulls, rule->name,
 				udebcomponents, &d->udebcomponents,
 				found);
 	}
-	for( i = 0 ; i < udebcomponents->count ; i++ ) {
-		if( found[i] )
+	for (i = 0 ; i < udebcomponents->count ; i++) {
+		if (found[i])
 			continue;
 		fprintf(stderr,
 "Warning: pull rule '%s' wants to %s udeb component '%s',\n"
@@ -546,17 +547,17 @@ static void checkifudebcomponentisused(const struct atomlist *udebcomponents, co
 static void checksubset(const struct atomlist *needed, const struct atomlist *have, const char *rulename, const char *from, const char *what, const char **atoms) {
 	int i, j;
 
-	for( i = 0 ; i < needed->count ; i++ ) {
+	for (i = 0 ; i < needed->count ; i++) {
 		atom_t value = needed->atoms[i];
 
-		for( j = 0 ; j < i ; j++ ) {
-			if( value == needed->atoms[j])
+		for (j = 0 ; j < i ; j++) {
+			if (value == needed->atoms[j])
 				break;
 		}
-		if( j < i )
+		if (j < i)
 			continue;
 
-		if( !atomlist_in(have, value) ) {
+		if (!atomlist_in(have, value)) {
 			fprintf(stderr,
 "Warning: pull rule '%s' wants to get something from %s '%s',\n"
 "but there is no such %s in distribution '%s'.\n"
@@ -568,7 +569,7 @@ static void checksubset(const struct atomlist *needed, const struct atomlist *ha
 }
 
 static void searchunused(const struct distribution *alldistributions, const struct pull_rule *rule) {
-	if( rule->distribution != NULL ) {
+	if (rule->distribution != NULL) {
 		// TODO: move this part of the checks into parsing?
 		checksubset(&rule->architectures_from,
 				&rule->distribution->architectures,
@@ -584,8 +585,8 @@ static void searchunused(const struct distribution *alldistributions, const stru
 				atoms_components);
 	}
 
-	if( rule->distribution == NULL ) {
-		assert( strcmp(rule->from, "*") == 0 );
+	if (rule->distribution == NULL) {
+		assert (strcmp(rule->from, "*") == 0);
 		checkifarchitectureisused(&rule->architectures_from,
 				alldistributions, rule, "get something from");
 		/* no need to check component and udebcomponent, as those
@@ -602,8 +603,8 @@ static void searchunused(const struct distribution *alldistributions, const stru
 static void pull_searchunused(const struct distribution *alldistributions, struct pull_rule *pull_rules) {
 	struct pull_rule *rule;
 
-	for( rule = pull_rules ; rule != NULL ; rule = rule->next ) {
-		if( !rule->used )
+	for (rule = pull_rules ; rule != NULL ; rule = rule->next) {
+		if (!rule->used)
 			continue;
 
 		searchunused(alldistributions, rule);
@@ -619,19 +620,19 @@ retvalue pull_prepare(struct distribution *alldistributions, struct pull_rule *r
 	retvalue r;
 
 	r = pull_init(&pulls, rules, alldistributions);
-	if( RET_WAS_ERROR(r) )
+	if (RET_WAS_ERROR(r))
 		return r;
 
 	r = pull_loadsourcedistributions(alldistributions, rules);
-	if( RET_WAS_ERROR(r) ) {
+	if (RET_WAS_ERROR(r)) {
 		pull_freedistributions(pulls);
 		return r;
 	}
-	if( !fast )
+	if (!fast)
 		pull_searchunused(alldistributions, rules);
 
 	r = pull_generatetargets(pulls);
-	if( RET_WAS_ERROR(r) ) {
+	if (RET_WAS_ERROR(r)) {
 		pull_freedistributions(pulls);
 		return r;
 	}
@@ -644,12 +645,36 @@ retvalue pull_prepare(struct distribution *alldistributions, struct pull_rule *r
  * decide what gets pulled                                                 *
  **************************************************************************/
 
-static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *target, const char *package, /*@null@*/const char *old_version, UNUSED(const char *new_version), const char *newcontrolchunk) {
+static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *target, const char *package, const char *sourcename, /*@null@*/const char *old_version, const char *new_version, const char *sourceversion, const char *newcontrolchunk) {
 	struct pull_rule *rule = privdata;
 	upgrade_decision decision = UD_UPGRADE;
 	retvalue r;
+	struct filterlist *fl;
+	const char *n, *v;
+	bool cmdline_still_undecided;
 
-	switch( filterlist_find(package,&rule->filterlist) ) {
+	if (target->packagetype == pt_dsc) {
+		assert (strcmp(package, sourcename) == 0);
+		assert (strcmp(new_version, sourceversion) == 0);
+		if (rule->filtersrclist.set)
+			fl = &rule->filtersrclist;
+		else
+			fl = &rule->filterlist;
+		n = package;
+		v = new_version;
+	} else {
+		if (rule->filterlist.set) {
+			fl = &rule->filterlist;
+			n = package;
+			v = new_version;
+		} else {
+			fl = &rule->filtersrclist;
+			n = sourcename;
+			v = sourceversion;
+		}
+	}
+
+	switch (filterlist_find(n, v, fl)) {
 		case flt_deinstall:
 		case flt_purge:
 			return UD_NO;
@@ -664,19 +689,93 @@ static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *t
 "Package name marked to be unexpected('error'): '%s'!\n", package);
 			return UD_ERROR;
 		case flt_upgradeonly:
-			if( old_version == NULL )
+			if (old_version == NULL)
 				return UD_NO;
 			break;
 		case flt_install:
 			break;
+		case flt_unchanged:
+		case flt_auto_hold:
+			assert (false);
+			break;
 	}
 
-	if( rule->includecondition != NULL ) {
+	cmdline_still_undecided = false;
+	switch (filterlist_find(sourcename, sourceversion,
+				&cmdline_src_filter)) {
+		case flt_deinstall:
+		case flt_purge:
+			return UD_NO;
+		case flt_warning:
+			return UD_LOUDNO;
+		case flt_auto_hold:
+			cmdline_still_undecided = true;
+			decision = UD_HOLD;
+			break;
+		case flt_hold:
+			decision = UD_HOLD;
+			break;
+		case flt_error:
+			/* cannot yet be handled! */
+			fprintf(stderr,
+"Package name marked to be unexpected('error'): '%s'!\n", package);
+			return UD_ERROR;
+		case flt_upgradeonly:
+			if (old_version == NULL)
+				return UD_NO;
+			break;
+		case flt_install:
+			decision = UD_UPGRADE;
+			break;
+		case flt_unchanged:
+			cmdline_still_undecided = true;
+			break;
+	}
+
+
+	if (target->packagetype != pt_dsc) {
+		switch (filterlist_find(package, new_version,
+					&cmdline_bin_filter)) {
+			case flt_deinstall:
+			case flt_purge:
+				return UD_NO;
+			case flt_warning:
+				return UD_LOUDNO;
+			case flt_hold:
+				decision = UD_HOLD;
+				break;
+			case flt_error:
+				/* cannot yet be handled! */
+				fprintf(stderr,
+"Package name marked to be unexpected('error'): '%s'!\n", package);
+				return UD_ERROR;
+			case flt_upgradeonly:
+				if (old_version == NULL)
+					return UD_NO;
+				break;
+			case flt_install:
+				decision = UD_UPGRADE;
+				break;
+			case flt_unchanged:
+				break;
+			case flt_auto_hold:
+				/* hold only if it was not in the src-filter */
+				if (cmdline_still_undecided)
+					decision = UD_HOLD;
+				break;
+		}
+	} else if (cmdline_bin_filter.defaulttype == flt_auto_hold) {
+		if (cmdline_still_undecided)
+			decision = UD_HOLD;
+	}
+
+	/* formula tested last as it is the most expensive */
+	if (rule->includecondition != NULL) {
 		r = term_decidechunktarget(rule->includecondition,
 				newcontrolchunk, target);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return UD_ERROR;
-		if( r == RET_NOTHING ) {
+		if (r == RET_NOTHING) {
 			return UD_NO;
 		}
 	}
@@ -684,55 +783,54 @@ static upgrade_decision ud_decide_by_rule(void *privdata, const struct target *t
 	return decision;
 }
 
-static inline retvalue pull_searchformissing(/*@null@*/FILE *out,struct database *database,struct pull_target *p) {
+static inline retvalue pull_searchformissing(/*@null@*/FILE *out, struct pull_target *p) {
 	struct pull_source *source;
-	retvalue result,r;
+	retvalue result, r;
 
-	if( verbose > 2 && out != NULL )
-		fprintf(out,"  pulling into '%s'\n",p->target->identifier);
+	if (verbose > 2 && out != NULL)
+		fprintf(out, "  pulling into '%s'\n", p->target->identifier);
 	assert(p->upgradelist == NULL);
-	r = upgradelist_initialize(&p->upgradelist, p->target, database);
-	if( RET_WAS_ERROR(r) )
+	r = upgradelist_initialize(&p->upgradelist, p->target);
+	if (RET_WAS_ERROR(r))
 		return r;
 
 	result = RET_NOTHING;
 
-	for( source=p->sources ; source != NULL ; source=source->next ) {
+	for (source=p->sources ; source != NULL ; source=source->next) {
 
-		if( source->rule == NULL ) {
-			if( verbose > 4 && out != NULL )
-				fprintf(out,"  marking everything to be deleted\n");
+		if (source->rule == NULL) {
+			if (verbose > 4 && out != NULL)
+				fprintf(out,
+"  marking everything to be deleted\n");
 			r = upgradelist_deleteall(p->upgradelist);
-			RET_UPDATE(result,r);
-			if( RET_WAS_ERROR(r) )
+			RET_UPDATE(result, r);
+			if (RET_WAS_ERROR(r))
 				return result;
 			continue;
 		}
 
-		if( verbose > 4 && out != NULL )
-			fprintf(out,"  looking what to get from '%s'\n",
+		if (verbose > 4 && out != NULL)
+			fprintf(out, "  looking what to get from '%s'\n",
 					source->source->identifier);
-		r = upgradelist_pull(p->upgradelist,
-				source->source,
-				ud_decide_by_rule, source->rule,
-				database, source);
-		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) )
+		r = upgradelist_pull(p->upgradelist, source->source,
+				ud_decide_by_rule, source->rule, source);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
 			return result;
 	}
 
 	return result;
 }
 
-static retvalue pull_search(/*@null@*/FILE *out,struct database *database,struct pull_distribution *d) {
-	retvalue result,r;
+static retvalue pull_search(/*@null@*/FILE *out, struct pull_distribution *d) {
+	retvalue result, r;
 	struct pull_target *u;
 
 	result = RET_NOTHING;
-	for( u=d->targets ; u != NULL ; u=u->next ) {
-		r = pull_searchformissing(out, database, u);
-		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) )
+	for (u=d->targets ; u != NULL ; u=u->next) {
+		r = pull_searchformissing(out, u);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
 			break;
 	}
 	return result;
@@ -741,10 +839,10 @@ static retvalue pull_search(/*@null@*/FILE *out,struct database *database,struct
 static bool pull_isbigdelete(struct pull_distribution *d) {
 	struct pull_target *u, *v;
 
-	for( u = d->targets ; u != NULL ; u=u->next ) {
-		if( upgradelist_isbigdelete(u->upgradelist) ) {
+	for (u = d->targets ; u != NULL ; u=u->next) {
+		if (upgradelist_isbigdelete(u->upgradelist)) {
 			d->distribution->omitted = true;
-			for( v = d->targets ; v != NULL ; v = v->next ) {
+			for (v = d->targets ; v != NULL ; v = v->next) {
 				upgradelist_free(v->upgradelist);
 				v->upgradelist = NULL;
 			}
@@ -762,27 +860,26 @@ static void pull_from_callback(void *privdata, const char **rule_p, const char *
 	*from_p = source->rule->from;
 }
 
-static retvalue pull_install(struct database *database, struct pull_distribution *distribution) {
-	retvalue result,r;
+static retvalue pull_install(struct pull_distribution *distribution) {
+	retvalue result, r;
 	struct pull_target *u;
 	struct distribution *d = distribution->distribution;
 
-	assert( logger_isprepared(d->logger) );
+	assert (logger_isprepared(d->logger));
 
 	result = RET_NOTHING;
-	for( u=distribution->targets ; u != NULL ; u=u->next ) {
+	for (u=distribution->targets ; u != NULL ; u=u->next) {
 		r = upgradelist_install(u->upgradelist, d->logger,
-				database, false,
-				pull_from_callback);
+				false, pull_from_callback);
 		RET_UPDATE(d->status, r);
-		RET_UPDATE(result,r);
+		RET_UPDATE(result, r);
 		upgradelist_free(u->upgradelist);
 		u->upgradelist = NULL;
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			break;
 	}
-	if( RET_IS_OK(result) && d->tracking != dt_NONE ) {
-		r = tracking_retrack(database, d, false);
+	if (RET_IS_OK(result) && d->tracking != dt_NONE) {
+		r = tracking_retrack(d, false);
 		RET_ENDUPDATE(result, r);
 	}
 	return result;
@@ -791,12 +888,12 @@ static retvalue pull_install(struct database *database, struct pull_distribution
 static void pull_dumppackage(const char *packagename, /*@null@*/const char *oldversion, /*@null@*/const char *newversion, /*@null@*/const char *bestcandidate, /*@null@*/const struct strlist *newfilekeys, /*@null@*/const char *newcontrol, void *privdata) {
 	struct pull_source *source = privdata;
 
-	if( newversion == NULL ) {
-		if( oldversion != NULL && bestcandidate != NULL ) {
+	if (newversion == NULL) {
+		if (oldversion != NULL && bestcandidate != NULL) {
 			printf("'%s': '%s' will be deleted"
 					" (best new: '%s')\n",
 					packagename, oldversion, bestcandidate);
-		} else if( oldversion != NULL ) {
+		} else if (oldversion != NULL) {
 			printf("'%s': '%s' will be deleted"
 					" (no longer available)\n",
 					packagename, oldversion);
@@ -804,15 +901,15 @@ static void pull_dumppackage(const char *packagename, /*@null@*/const char *oldv
 			printf("'%s': will NOT be added as '%s'\n",
 					packagename, bestcandidate);
 		}
-	} else if( newversion == oldversion ) {
-		if( bestcandidate != NULL ) {
-			if( verbose > 1 )
+	} else if (newversion == oldversion) {
+		if (bestcandidate != NULL) {
+			if (verbose > 1)
 				printf("'%s': '%s' will be kept"
 						" (best new: '%s')\n",
 						packagename, oldversion,
 						bestcandidate);
 		} else {
-			if( verbose > 0 )
+			if (verbose > 0)
 				printf("'%s': '%s' will be kept"
 						" (unavailable for reload)\n",
 						packagename, oldversion);
@@ -820,9 +917,9 @@ static void pull_dumppackage(const char *packagename, /*@null@*/const char *oldv
 	} else {
 		const char *via = source->rule->name;
 
-		assert( newfilekeys != NULL );
-		assert( newcontrol != NULL );
-		if( oldversion != NULL )
+		assert (newfilekeys != NULL);
+		assert (newcontrol != NULL);
+		if (oldversion != NULL)
 			(void)printf("'%s': '%s' will be upgraded"
 					" to '%s' (from '%s'):\n files needed: ",
 					packagename, oldversion,
@@ -832,7 +929,7 @@ static void pull_dumppackage(const char *packagename, /*@null@*/const char *oldv
 					" as '%s' (from '%s'):\n files needed: ",
 					packagename, newversion, via);
 		(void)strlist_fprint(stdout, newfilekeys);
-		if( verbose > 2)
+		if (verbose > 2)
 			(void)printf("\n installing as: '%s'\n",
 					newcontrol);
 		else
@@ -843,8 +940,8 @@ static void pull_dumppackage(const char *packagename, /*@null@*/const char *oldv
 static void pull_dump(struct pull_distribution *distribution) {
 	struct pull_target *u;
 
-	for( u=distribution->targets ; u != NULL ; u=u->next ) {
-		if( u->upgradelist == NULL )
+	for (u=distribution->targets ; u != NULL ; u=u->next) {
+		if (u->upgradelist == NULL)
 			continue;
 		printf("Updates needed for '%s':\n", u->target->identifier);
 		upgradelist_dump(u->upgradelist, pull_dumppackage);
@@ -856,12 +953,12 @@ static void pull_dump(struct pull_distribution *distribution) {
 static void pull_dumplistpackage(const char *packagename, /*@null@*/const char *oldversion, /*@null@*/const char *newversion, /*@null@*/const char *bestcandidate, /*@null@*/const struct strlist *newfilekeys, /*@null@*/const char *newcontrol, void *privdata) {
 	struct pull_source *source = privdata;
 
-	if( newversion == NULL ) {
-		if( oldversion == NULL )
+	if (newversion == NULL) {
+		if (oldversion == NULL)
 			return;
 		printf("delete '%s' '%s'\n", packagename, oldversion);
-	} else if( newversion == oldversion ) {
-		if( bestcandidate != NULL )
+	} else if (newversion == oldversion) {
+		if (bestcandidate != NULL)
 			printf("keep '%s' '%s' '%s'\n", packagename,
 					oldversion, bestcandidate);
 		else
@@ -870,9 +967,9 @@ static void pull_dumplistpackage(const char *packagename, /*@null@*/const char *
 	} else {
 		const char *via = source->rule->name;
 
-		assert( newfilekeys != NULL );
-		assert( newcontrol != NULL );
-		if( oldversion != NULL )
+		assert (newfilekeys != NULL);
+		assert (newcontrol != NULL);
+		if (oldversion != NULL)
 			(void)printf("update '%s' '%s' '%s' '%s'\n",
 					packagename, oldversion,
 					newversion, via);
@@ -885,8 +982,8 @@ static void pull_dumplistpackage(const char *packagename, /*@null@*/const char *
 static void pull_dumplist(struct pull_distribution *distribution) {
 	struct pull_target *u;
 
-	for( u=distribution->targets ; u != NULL ; u=u->next ) {
-		if( u->upgradelist == NULL )
+	for (u=distribution->targets ; u != NULL ; u=u->next) {
+		if (u->upgradelist == NULL)
 			continue;
 		printf("Updates needed for '%s':\n", u->target->identifier);
 		upgradelist_dump(u->upgradelist, pull_dumplistpackage);
@@ -895,56 +992,56 @@ static void pull_dumplist(struct pull_distribution *distribution) {
 	}
 }
 
-retvalue pull_update(struct database *database, struct pull_distribution *distributions) {
-	retvalue result,r;
+retvalue pull_update(struct pull_distribution *distributions) {
+	retvalue result, r;
 	struct pull_distribution *d;
 
-	for( d=distributions ; d != NULL ; d=d->next) {
+	for (d=distributions ; d != NULL ; d=d->next) {
 		r = distribution_prepareforwriting(d->distribution);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 		r = distribution_loadalloverrides(d->distribution);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 	}
 
-	if( verbose >= 0 )
+	if (verbose >= 0)
 		printf("Calculating packages to pull...\n");
 
 	result = RET_NOTHING;
 
-	for( d=distributions ; d != NULL ; d=d->next) {
-		r = pull_search(stdout, database, d);
-		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) )
+	for (d=distributions ; d != NULL ; d=d->next) {
+		r = pull_search(stdout, d);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
 			break;
 		// TODO: make already here sure the files are ready?
 	}
-	if( RET_WAS_ERROR(result) ) {
-		for( d=distributions ; d != NULL ; d=d->next) {
+	if (RET_WAS_ERROR(result)) {
+		for (d=distributions ; d != NULL ; d=d->next) {
 			struct pull_target *u;
-			for( u=d->targets ; u != NULL ; u=u->next ) {
+			for (u=d->targets ; u != NULL ; u=u->next) {
 				upgradelist_free(u->upgradelist);
 				u->upgradelist = NULL;
 			}
 		}
 		return result;
 	}
-	if( verbose >= 0 )
+	if (verbose >= 0)
 		printf("Installing (and possibly deleting) packages...\n");
 
-	for( d=distributions ; d != NULL ; d=d->next) {
-		if( global.onlysmalldeletes ) {
-			if( pull_isbigdelete(d) ) {
+	for (d=distributions ; d != NULL ; d=d->next) {
+		if (global.onlysmalldeletes) {
+			if (pull_isbigdelete(d)) {
 				fprintf(stderr,
 "Not processing '%s' because of --onlysmalldeletes\n",
 						d->distribution->codename);
 				continue;
 			}
 		}
-		r = pull_install(database, d);
-		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) )
+		r = pull_install(d);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
 			break;
 	}
 	logger_wait();
@@ -952,25 +1049,25 @@ retvalue pull_update(struct database *database, struct pull_distribution *distri
 	return result;
 }
 
-retvalue pull_checkupdate(struct database *database, struct pull_distribution *distributions) {
+retvalue pull_checkupdate(struct pull_distribution *distributions) {
 	struct pull_distribution *d;
-	retvalue result,r;
+	retvalue result, r;
 
-	for( d=distributions ; d != NULL ; d=d->next) {
+	for (d=distributions ; d != NULL ; d=d->next) {
 		r = distribution_loadalloverrides(d->distribution);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 	}
 
-	if( verbose >= 0 )
-		fprintf(stderr,"Calculating packages to get...\n");
+	if (verbose >= 0)
+		fprintf(stderr, "Calculating packages to get...\n");
 
 	result = RET_NOTHING;
 
-	for( d=distributions ; d != NULL ; d=d->next) {
-		r = pull_search(stderr, database, d);
-		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) )
+	for (d=distributions ; d != NULL ; d=d->next) {
+		r = pull_search(stderr, d);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
 			break;
 		pull_dump(d);
 	}
@@ -978,22 +1075,22 @@ retvalue pull_checkupdate(struct database *database, struct pull_distribution *d
 	return result;
 }
 
-retvalue pull_dumpupdate(struct database *database, struct pull_distribution *distributions) {
+retvalue pull_dumpupdate(struct pull_distribution *distributions) {
 	struct pull_distribution *d;
-	retvalue result,r;
+	retvalue result, r;
 
-	for( d=distributions ; d != NULL ; d=d->next) {
+	for (d=distributions ; d != NULL ; d=d->next) {
 		r = distribution_loadalloverrides(d->distribution);
-		if( RET_WAS_ERROR(r) )
+		if (RET_WAS_ERROR(r))
 			return r;
 	}
 
 	result = RET_NOTHING;
 
-	for( d=distributions ; d != NULL ; d=d->next) {
-		r = pull_search(NULL, database, d);
-		RET_UPDATE(result,r);
-		if( RET_WAS_ERROR(r) )
+	for (d=distributions ; d != NULL ; d=d->next) {
+		r = pull_search(NULL, d);
+		RET_UPDATE(result, r);
+		if (RET_WAS_ERROR(r))
 			break;
 		pull_dumplist(d);
 	}
