@@ -32,17 +32,17 @@ typedef retvalue get_installdata(const struct target *, const char *, const char
 /* md5sums may be NULL */
 typedef retvalue get_filekeys(const char *, /*@out@*/struct strlist *);
 typedef retvalue get_checksums(const char *, /*@out@*/struct checksumsarray *);
-typedef retvalue do_reoverride(const struct target *, const char *packagename, const char *controlchunk, /*@out@*/char **newcontrolchunk);
-typedef retvalue do_retrack(const char *packagename, const char *controlchunk, trackingdb, struct database *);
-typedef retvalue get_sourceandversion(const char *chunk, const char *packagename, /*@out@*/char **source, /*@out@*/char **version);
-typedef retvalue complete_checksums(const char *chunk, const struct strlist *, struct checksums **, /*@out@*/char **);
+typedef retvalue do_reoverride(const struct target *, const char * /*packagename*/, const char *, /*@out@*/char **);
+typedef retvalue do_retrack(const char * /*packagename*/, const char * /*controlchunk*/, trackingdb);
+typedef retvalue get_sourceandversion(const char *, const char * /*packagename*/, /*@out@*/char ** /*source_p*/, /*@out@*/char ** /*version_p*/);
+typedef retvalue complete_checksums(const char *, const struct strlist *, struct checksums **, /*@out@*/char **);
 
 struct distribution;
 struct target {
 	struct distribution *distribution;
-	component_t component_atom;
-	architecture_t architecture_atom;
-	packagetype_t packagetype_atom;
+	component_t component;
+	architecture_t architecture;
+	packagetype_t packagetype;
 	char *identifier;
 	/* links into the correct description in distribution */
 	/*@dependent@*/const struct exportmode *exportmode;
@@ -73,19 +73,17 @@ struct target {
 	bool staletracking;
 };
 
-retvalue target_initialize_ubinary(/*@dependant@*/struct distribution *, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
-retvalue target_initialize_binary(/*@dependant@*/struct distribution *, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
-retvalue target_initialize_source(/*@dependant@*/struct distribution *, component_t, /*@dependent@*/const struct exportmode *, bool readonly, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
-retvalue target_free(struct target *target);
+retvalue target_initialize_ubinary(/*@dependant@*/struct distribution *, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool /*readonly*/, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
+retvalue target_initialize_binary(/*@dependant@*/struct distribution *, component_t, architecture_t, /*@dependent@*/const struct exportmode *, bool /*readonly*/, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
+retvalue target_initialize_source(/*@dependant@*/struct distribution *, component_t, /*@dependent@*/const struct exportmode *, bool /*readonly*/, /*@NULL@*/const char *fakecomponentprefix, /*@out@*/struct target **);
+retvalue target_free(struct target *);
 
-retvalue target_export(struct target *target, struct database *, bool onlyneeded, bool snapshot, struct release *release);
-
-retvalue target_printmd5sums(const char *dirofdist,const struct target *target,FILE *out,int force);
+retvalue target_export(struct target *, bool /*onlyneeded*/, bool /*snapshot*/, struct release *);
 
 /* This opens up the database, if db != NULL, *db will be set to it.. */
-retvalue target_initpackagesdb(struct target *target, struct database *, bool readonly);
+retvalue target_initpackagesdb(struct target *, bool /*readonly*/);
 /* this closes databases... */
-retvalue target_closepackagesdb(struct target *target);
+retvalue target_closepackagesdb(struct target *);
 
 struct target_cursor {
 	/*@temp@*/struct target *target;
@@ -95,17 +93,17 @@ struct target_cursor {
 };
 #define TARGET_CURSOR_ZERO {NULL, NULL, NULL, NULL}
 /* wrapper around initpackagesdb and table_newglobalcursor */
-static inline retvalue target_openiterator(struct target *t, struct database *db, bool readonly, /*@out@*/struct target_cursor *tc) {
+static inline retvalue target_openiterator(struct target *t, bool readonly, /*@out@*/struct target_cursor *tc) {
 	retvalue r, r2;
 	struct cursor *c;
 
-	r = target_initpackagesdb(t, db, readonly);
-	assert( r != RET_NOTHING );
-	if( RET_WAS_ERROR(r) )
+	r = target_initpackagesdb(t, readonly);
+	assert (r != RET_NOTHING);
+	if (RET_WAS_ERROR(r))
 		return r;
 	r = table_newglobalcursor(t->packages, &c);
-	assert( r != RET_NOTHING );
-	if( RET_WAS_ERROR(r) ) {
+	assert (r != RET_NOTHING);
+	if (RET_WAS_ERROR(r)) {
 		r2 = target_closepackagesdb(t);
 		RET_UPDATE(r, r2);
 		return r;
@@ -119,7 +117,7 @@ static inline bool target_nextpackage(struct target_cursor *tc, /*@out@*/const c
 	bool success;
 	success = cursor_nexttemp(tc->target->packages, tc->cursor,
 			&tc->lastname, &tc->lastcontrol);
-	if( success ) {
+	if (success) {
 		*packagename_p = tc->lastname;
 		*chunk_p = tc->lastcontrol;
 	} else {
@@ -147,27 +145,27 @@ static inline retvalue target_closeiterator(struct target_cursor *tc) {
 
 /* The following calls can only be called if target_initpackagesdb was called before: */
 struct logger;
-retvalue target_addpackage(struct target *, /*@null@*/struct logger *, struct database *, const char *name, const char *version, const char *control, const struct strlist *filekeys, bool downgrade, /*@null@*/struct trackingdata *, enum filetype, /*@null@*/const char *causingrule, /*@null@*/const char *suitefrom);
-retvalue target_checkaddpackage(struct target *target, const char *name, const char *version, bool tracking, bool permitnewerold);
-retvalue target_removepackage(struct target *, /*@null@*/struct logger *, struct database *, const char *name, struct trackingdata *);
+retvalue target_addpackage(struct target *, /*@null@*/struct logger *, const char *name, const char *version, const char *control, const struct strlist *filekeys, bool downgrade, /*@null@*/struct trackingdata *, enum filetype, /*@null@*/const char *causingrule, /*@null@*/const char *suitefrom);
+retvalue target_checkaddpackage(struct target *, const char *name, const char *version, bool tracking, bool permitnewerold);
+retvalue target_removepackage(struct target *, /*@null@*/struct logger *, const char *name, struct trackingdata *);
 /* like target_removepackage, but do not read control data yourself but use available */
-retvalue target_removereadpackage(struct target *, /*@null@*/struct logger *, struct database *, const char *name, const char *oldcontrol, /*@null@*/struct trackingdata *);
+retvalue target_removereadpackage(struct target *, /*@null@*/struct logger *, const char *name, const char *oldcontrol, /*@null@*/struct trackingdata *);
 /* Like target_removepackage, but delete the package record by cursor */
-retvalue target_removepackage_by_cursor(struct target_cursor *, /*@null@*/struct logger *, struct database *, /*@null@*/struct trackingdata *);
+retvalue target_removepackage_by_cursor(struct target_cursor *, /*@null@*/struct logger *, /*@null@*/struct trackingdata *);
 
-retvalue package_check(struct database *, struct distribution *, struct target *, const char *, const char *, void *);
-retvalue target_rereference(struct target *, struct database *);
-retvalue package_referenceforsnapshot(struct database *, struct distribution *, struct target *, const char *, const char *, void *);
-retvalue target_reoverride(struct target *, struct distribution *, struct database *);
+retvalue package_check(struct distribution *, struct target *, const char *, const char *, void *);
+retvalue target_rereference(struct target *);
+retvalue package_referenceforsnapshot(struct distribution *, struct target *, const char *, const char *, void *);
+retvalue target_reoverride(struct target *, struct distribution *);
 
-retvalue package_rerunnotifiers(struct database *, struct distribution *, struct target *, const char *, const char *, void *);
+retvalue package_rerunnotifiers(struct distribution *, struct target *, const char *, const char *, void *);
 
 static inline bool target_matches(const struct target *t, const struct atomlist *components, const struct atomlist *architectures, const struct atomlist *packagetypes) {
-	if( limitations_missed(components, t->component_atom) )
+	if (limitations_missed(components, t->component))
 		return false;
-	if( limitations_missed(architectures, t->architecture_atom) )
+	if (limitations_missed(architectures, t->architecture))
 		return false;
-	if( limitations_missed(packagetypes, t->packagetype_atom) )
+	if (limitations_missed(packagetypes, t->packagetype))
 		return false;
 	return true;
 }
